==> nextcloud-29.0.12.tgz: nextcloud/apps/weather_status/l10n/sr.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Непозната адреса",
    "No result." : "Нема резултата.",
    "Malformed JSON data." : "Неисправни JSON подаци.",
    "Error" : "Грешка",
    "Weather status" : "Временска прогноза",
    "Weather status in your dashboard" : "Временска прогноза на Вашој контролној табли",
    "Weather status integrated in the Dashboard app.\n    The geographic location can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Временска прогноза интегрисана на Контролној табли.\n    Географска локација се може аутоматски одредити или ручно подесити. Затим се приказује прогноза за наредних 6 сати.\n    Овај статус се такође може интегрисати на друга места, као што је Календар.",
    "Detect location" : "Откриј локацију",
    "Set custom address" : "Постави произвољну адресу",
    "Favorites" : "Омиљене",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} ведро касније данас",
    "{temperature} {unit} clear sky" : "{temperature} {unit} ведро",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} облачно касније данас",
    "{temperature} {unit} cloudy" : "{temperature} {unit} облачно",
    "{temperature} {unit} snow and thunder later today" : "{temperature} {unit} снег и грмљавина касније данас",
    "{temperature} {unit} snow and thunder" : "{temperature} {unit} снег и грмљавина",
    "{temperature} {unit} snow showers and thunder later today" : "{temperature} {unit} вејавица и грмљавина касније данас",
    "{temperature} {unit} snow showers and thunder" : "{temperature} {unit} вејавица и грмљавина",
    "{temperature} {unit} snow showers, thunder and polar twilight later today" : "{temperature} {unit} вејавица, грмљавина и поларни сумрак касније данас",
    "{temperature} {unit} snow showers, thunder and polar twilight" : "{temperature} {unit} вејавица, грмљавина и поларни сумрак",
    "{temperature} {unit} snow showers later today" : "{temperature} {unit} вејавица касније данас",
    "{temperature} {unit} snow showers" : "{temperature} {unit} вејавица",
    "{temperature} {unit} snow showers and polar twilight later today" : "{temperature} {unit} вејавица и поларни сумрак касније данас",
    "{temperature} {unit} snow showers and polar twilight" : "{temperature} {unit} вејавица и поларни сумрак",
    "{temperature} {unit} snow later today" : "{temperature} {unit} снег касније данас",
    "{temperature} {unit} snow" : "{temperature} {unit} снег",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} лепо време касније данас",
    "{temperature} {unit} fair weather" : "{temperature} {unit} лепо време",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} делимично облачно касније данас",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} делимично облачно",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} магловито касније данас",
    "{temperature} {unit} foggy" : "{temperature} {unit} магловито",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} слаба киша касније данас",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} слаба киша",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} киша касније данас",
    "{temperature} {unit} rainfall" : "{temperature} {unit} киша",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} јака киша касније данас",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} јака киша",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} пљускови касније данас",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} пљускови",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} слаби пљускови касније данас",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} слаби пљускови",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} јаки пљускови касније данас",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} јаки пљускови",
    "More weather for {adr}" : "Још прогнозе за {adr}",
    "Loading weather" : "Учитавам прогнозу",
    "Set location for weather" : "Постави локацију за прогнозу",
    "Remove from favorites" : "Уклони из омиљених",
    "Add as favorite" : "Додај као омиљено",
    "You are not logged in." : "Нисте пријављени.",
    "There was an error getting the weather status information." : "Грешка приликом дохватања прогнозе времена.",
    "No weather information found" : "Прогноза није нађена",
    "Location not found" : "Локација није нађена",
    "There was an error setting the location address." : "Грешка приликом постављања адресе локације.",
    "There was an error setting the location." : "Грешка приликом постављања локације.",
    "There was an error saving the mode." : "Грешка приликом чувања режима.",
    "There was an error using personal address." : "Грешка приликом коришћења личне адресе.",
    "Unknown weather code" : "Непознати код временских прилика"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-31.0.11.tgz: nextcloud/apps/weather_status/l10n/sr.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Непозната адреса",
    "No result." : "Нема резултата.",
    "Malformed JSON data." : "Неисправни JSON подаци.",
    "Error" : "Грешка",
    "Weather status" : "Временска прогноза",
    "Weather status in your dashboard" : "Временска прогноза на Вашој контролној табли",
    "Weather status integrated in the Dashboard app.\n    The geographic location can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Временска прогноза интегрисана на Контролној табли.\n    Географска локација се може аутоматски одредити или ручно подесити. Затим се приказује прогноза за наредних 6 сати.\n    Овај статус се такође може интегрисати на друга места, као што је Календар.",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} ведро касније данас",
    "{temperature} {unit} clear sky" : "{temperature} {unit} ведро",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} облачно касније данас",
    "{temperature} {unit} cloudy" : "{temperature} {unit} облачно",
    "{temperature} {unit} snow and thunder later today" : "{temperature} {unit} снег и грмљавина касније данас",
    "{temperature} {unit} snow and thunder" : "{temperature} {unit} снег и грмљавина",
    "{temperature} {unit} snow showers and thunder later today" : "{temperature} {unit} вејавица и грмљавина касније данас",
    "{temperature} {unit} snow showers and thunder" : "{temperature} {unit} вејавица и грмљавина",
    "{temperature} {unit} snow showers, thunder and polar twilight later today" : "{temperature} {unit} вејавица, грмљавина и поларни сумрак касније данас",
    "{temperature} {unit} snow showers, thunder and polar twilight" : "{temperature} {unit} вејавица, грмљавина и поларни сумрак",
    "{temperature} {unit} snow showers later today" : "{temperature} {unit} вејавица касније данас",
    "{temperature} {unit} snow showers" : "{temperature} {unit} вејавица",
    "{temperature} {unit} snow showers and polar twilight later today" : "{temperature} {unit} вејавица и поларни сумрак касније данас",
    "{temperature} {unit} snow showers and polar twilight" : "{temperature} {unit} вејавица и поларни сумрак",
    "{temperature} {unit} snow later today" : "{temperature} {unit} снег касније данас",
    "{temperature} {unit} snow" : "{temperature} {unit} снег",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} лепо време касније данас",
    "{temperature} {unit} fair weather" : "{temperature} {unit} лепо време",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} делимично облачно касније данас",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} делимично облачно",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} магловито касније данас",
    "{temperature} {unit} foggy" : "{temperature} {unit} магловито",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} слаба киша касније данас",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} слаба киша",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} киша касније данас",
    "{temperature} {unit} rainfall" : "{temperature} {unit} киша",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} јака киша касније данас",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} јака киша",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} пљускови касније данас",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} пљускови",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} слаби пљускови касније данас",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} слаби пљускови",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} јаки пљускови касније данас",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} јаки пљускови",
    "More weather for {adr}" : "Још прогнозе за {adr}",
    "Loading weather" : "Учитавам прогнозу",
    "Set location for weather" : "Постави локацију за прогнозу",
    "Remove from favorites" : "Уклони из омиљених",
    "Add as favorite" : "Додај као омиљено",
    "You are not logged in." : "Нисте пријављени.",
    "There was an error getting the weather status information." : "Грешка приликом дохватања прогнозе времена.",
    "No weather information found" : "Прогноза није нађена",
    "Location not found" : "Локација није нађена",
    "There was an error setting the location address." : "Грешка приликом постављања адресе локације.",
    "There was an error setting the location." : "Грешка приликом постављања локације.",
    "There was an error saving the mode." : "Грешка приликом чувања режима.",
    "There was an error using personal address." : "Грешка приликом коришћења личне адресе.",
    "Unknown weather code" : "Непознати код временских прилика",
    "Detect location" : "Откриј локацију",
    "Set custom address" : "Постави произвољну адресу",
    "Favorites" : "Омиљене"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
